package com.ruoyi.business.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.business.mapper.AiUserLabelMapper;
import com.ruoyi.business.domain.AiUserLabel;
import com.ruoyi.business.service.IAiUserLabelService;
import com.ruoyi.common.core.text.Convert;

/**
 * 用户标签Service业务层处理
 * 
 * @author max
 * @date 2023-05-14
 */
@Service
public class AiUserLabelServiceImpl implements IAiUserLabelService 
{
    @Autowired
    private AiUserLabelMapper aiUserLabelMapper;

    /**
     * 查询用户标签
     * 
     * @param id 用户标签主键
     * @return 用户标签
     */
    @Override
    public AiUserLabel selectAiUserLabelById(Long id)
    {
        return aiUserLabelMapper.selectAiUserLabelById(id);
    }

    /**
     * 查询用户标签列表
     * 
     * @param aiUserLabel 用户标签
     * @return 用户标签
     */
    @Override
    public List<AiUserLabel> selectAiUserLabelList(AiUserLabel aiUserLabel)
    {
        return aiUserLabelMapper.selectAiUserLabelList(aiUserLabel);
    }

    /**
     * 新增用户标签
     * 
     * @param aiUserLabel 用户标签
     * @return 结果
     */
    @Override
    public int insertAiUserLabel(AiUserLabel aiUserLabel)
    {
        return aiUserLabelMapper.insertAiUserLabel(aiUserLabel);
    }

    /**
     * 修改用户标签
     * 
     * @param aiUserLabel 用户标签
     * @return 结果
     */
    @Override
    public int updateAiUserLabel(AiUserLabel aiUserLabel)
    {
        return aiUserLabelMapper.updateAiUserLabel(aiUserLabel);
    }

    /**
     * 批量删除用户标签
     * 
     * @param ids 需要删除的用户标签主键
     * @return 结果
     */
    @Override
    public int deleteAiUserLabelByIds(String ids)
    {
        return aiUserLabelMapper.deleteAiUserLabelByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除用户标签信息
     * 
     * @param id 用户标签主键
     * @return 结果
     */
    @Override
    public int deleteAiUserLabelById(Long id)
    {
        return aiUserLabelMapper.deleteAiUserLabelById(id);
    }
}
